function y=D_A(omega_m, p) 
% D_A Power noise spectral density of noise in the amplitude channel. 
%
%   Y = D_A(omega_m, p) calculates the power spectral density of the 
%     amplitude signal noise as a function of the modulation frequency 
%     omega_m with omega = omega_0 + omega_m with the cantilever 
%     eigenfrequency omega_0
%     p is the parameter struct, see parameters_default. 
%     The formula follows [1].
%
%   Following entries are accessed in parameter struct p:
%   p.CL.f0           : cantilever eigenfrequency (in Hz)
%   p.CL.Q            : cantilever quality factor
%   p.CL.k            : cantilever stiffness (in N/m)
%   p.CL.T            : cantilever temperature (in K)
%   p.AFB.Pgain       : proportional gain for the PID loop
%   p.AFB.Igain       : integral gain for the PID loop
%   p.AFB.Dgain       : differential gain for the PID loop
%   p.AFB.filter_type : filter type of low-pass filter
%   p.AFB.filter_fc   : cutoff frequency of low-pass filter (in Hz)
%   p.SYS.dzds        : detection system noise amplitude spectral density
%   p.SYS.S_z_A   : sensitivity of detection system in m/V
%   p.SYS.S_z_exc : sensitivity of the drive piezo in m/V
%
%   [1] Polesel-Maris et al., Phys. Rev. B 79, 235401 (2009)
%
%   See also H_Csimple, H_ac, D_exc_th, parameters_default
%
%   Copyright 2016 
%   Jannis Luebbe, Matthias Temmen, Philipp Rahe, Michael Reichling
%
%   This work is licensed under the Creative Commons 
%   Attribution-NonCommercial 4.0 International License, which permits 
%   non-commercial unrestricted use, distribution and reproduction 
%   provided the original work is properly cited. To view a copy of 
%   this license, visit http://creativecommons.org/licenses/by-nc/4.0/.
%
%   The software is provided "as is", without warranty of any kind, 
%   express or implied, including but not limited to the warranties of 
%   merchantability, fitness for a particular purpose and noninfringement. 
%   In no event shall the authors or copyright holders be liable for any 
%   claim, damages or other liability, whether in an action of contract, 
%   tort or otherwise, arising from, out of or in connection with the 
%   software or the use or other dealings in the software.
%
  
  % cantilever transfer function
  myHC = H_Csimple(omega_m,p);
  % frequency response of amplitude controller
  myHac    = H_ac(omega_m, p);
  % low-pass filter in the PLL loop
  myHlp    = feval(p.AFB.filter_type, omega_m, 2.*pi.*p.AFB.filter_fc);
  % noise power spectral density of the thermal cantilever excitation
  myDexcth = D_exc_th(p);

  y= 2.*abs(myHlp./(1-myHC.*myHlp.*myHac)).^2 ...
      .*( abs(myHC).^2.*myDexcth + p.SYS.dzds.^2 );
  
end
