function y=D_zp(omega_m, p) 
% D_ZP Power noise spectral density of noise in the topography channel
%
%   Y = D_ZP(omega_m, p) calculates the power spectral density of the 
%     topography signal noise as a function of the modulation frequency 
%     omega_m with omega = omega_0 + omega_m with the cantilever 
%     eigenfrequency omega_0
%     p is the parameter struct, see parameters_default. 
%     The formula follows [1].
%
%   Following entries are accessed in parameter struct p:
%   p.CL.f0           : cantilever eigenfrequency (in Hz)
%   p.CL.Q            : cantilever quality factor
%   p.CL.k            : cantilever stiffness (in N/m)
%   p.CL.T            : cantilever temperature (in K)
%   p.CL.A            : cantilever oscillation amplitude zero-peak (in m)
%   p.ZFB.Szp         : Piezo sensitivity including amplifier gain (in m/V)
%   p.ZFB.Pgain       : proportional gain for the PID loop
%   p.ZFB.Igain       : integral gain for the PID loop
%   p.ZFB.Dgain       : differential gain for the PID loop
%   p.AFB.Pgain       : proportional gain for the PID loop
%   p.AFB.Igain       : integral gain for the PID loop
%   p.AFB.Dgain       : differential gain for the PID loop
%   p.AFB.filter_type : filter type of low-pass filter
%   p.AFB.filter_fc   : cutoff frequency of low-pass filter (in Hz)
%   p.PLL.Sdf         : Df scaling on PLL input (in Hz/V)
%   p.PLL.filter_type : filter type of loop filter
%   p.PLL.filter_fc   : cutoff frequency of loop filter (in Hz)
%   p.PLL.Pgain       : proportional gain for the PID loop
%   p.PLL.Igain       : integral gain for the PID loop
%   p.PLL.Dgain       : differential gain for the PID loop
%   p.TS.alpha        : parameter alpha describing the tip-sample
%                       interaction
%   p.TS.beta         : parameter beta describing the tip-sample
%                       interaction
%   p.SYS.dzds        : detection system noise amplitude spectral density
%   p.SYS.S_z_A   : sensitivity of detection system in m/V
%   p.SYS.S_z_exc : sensitivity of the drive piezo in m/V
%
%   [1] Polesel-Maris et al., Phys. Rev. B 79, 235401 (2009)
%
%   See also H_zc, D_df
%
%   Copyright 2016 
%   Jannis Luebbe, Matthias Temmen, Philipp Rahe, Michael Reichling
%
%   This work is licensed under the Creative Commons 
%   Attribution-NonCommercial 4.0 International License, which permits 
%   non-commercial unrestricted use, distribution and reproduction 
%   provided the original work is properly cited. To view a copy of 
%   this license, visit http://creativecommons.org/licenses/by-nc/4.0/.
%
%   The software is provided "as is", without warranty of any kind, 
%   express or implied, including but not limited to the warranties of 
%   merchantability, fitness for a particular purpose and noninfringement. 
%   In no event shall the authors or copyright holders be liable for any 
%   claim, damages or other liability, whether in an action of contract, 
%   tort or otherwise, arising from, out of or in connection with the 
%   software or the use or other dealings in the software.
%
  
  % frequency response of amplitude controller
  myHzc    = H_zc(omega_m, p);
  % total df noise
  myDdfts  = D_df(omega_m, p);

  y = abs(myHzc).^2 .* myDdfts;
  
end
